#!/usr/bin/python3

import sys
import os
import gi

gi.require_version('Adw', '1')
gi.require_version('Gtk', '4.0')
from gi.repository import Gtk, Adw, GLib, Gio

from .window import KrbPassWindow
from .utils import get_realms, _

# Application metadata
APP_ID = "com.softline.krbpass"
VERSION = "1.0.0"
APP_NAME = "KrbPass"

class KrbPassApplication(Adw.Application):
    """GNOME Kerberos Password Change Application"""

    def __init__(self):
        super().__init__(application_id=APP_ID,
                         flags=Gio.ApplicationFlags.FLAGS_NONE)

        self.add_main_option(
            "version", ord("v"), GLib.OptionFlags.NONE, GLib.OptionArg.NONE,
            _("Show the application version"), None
        )

    def do_activate(self):
        """Called when the application is activated"""
        win = self.props.active_window
        if not win:
            win = KrbPassWindow(application=self)
        win.present()

    def do_startup(self):
        """Application startup"""
        Adw.Application.do_startup(self)
        GLib.set_application_name(APP_NAME)

    def do_handle_local_options(self, options):
        """Handle command line options"""
        if options.contains("version"):
            print(f"{APP_NAME} {VERSION}")
            return 0
        return -1


def main(version=None):
    """Main entry point"""
    realms = get_realms()
    if not realms:
        print(_("No available realms"))
    else:
        print(_("Available realms: "), *map(str, realms.keys()))
    app = KrbPassApplication()
    return app.run(sys.argv)


if __name__ == "__main__":
    sys.exit(main())
